"""
HACK: this file is ugly, but necessary for pyright work
"""

import evdev.ecodes as e

# HACK: To declare as int, declare them as 1
KEY_0 = e.KEY_0  # type:ignore
KEY_1 = e.KEY_1  # type:ignore
KEY_102ND = e.KEY_102ND  # type:ignore
KEY_10CHANNELSDOWN = e.KEY_10CHANNELSDOWN  # type:ignore
KEY_10CHANNELSUP = e.KEY_10CHANNELSUP  # type:ignore
KEY_2 = e.KEY_2  # type:ignore
KEY_3 = e.KEY_3  # type:ignore
KEY_3D_MODE = e.KEY_3D_MODE  # type:ignore
KEY_4 = e.KEY_4  # type:ignore
KEY_5 = e.KEY_5  # type:ignore
KEY_6 = e.KEY_6  # type:ignore
KEY_7 = e.KEY_7  # type:ignore
KEY_8 = e.KEY_8  # type:ignore
KEY_9 = e.KEY_9  # type:ignore
KEY_A = e.KEY_A  # type:ignore
KEY_AB = e.KEY_AB  # type:ignore
KEY_ADDRESSBOOK = e.KEY_ADDRESSBOOK  # type:ignore
KEY_AGAIN = e.KEY_AGAIN  # type:ignore
KEY_ALS_TOGGLE = e.KEY_ALS_TOGGLE  # type:ignore
KEY_ALTERASE = e.KEY_ALTERASE  # type:ignore
KEY_ANGLE = e.KEY_ANGLE  # type:ignore
KEY_APOSTROPHE = e.KEY_APOSTROPHE  # type:ignore
KEY_APPSELECT = e.KEY_APPSELECT  # type:ignore
KEY_ARCHIVE = e.KEY_ARCHIVE  # type:ignore
KEY_ASPECT_RATIO = e.KEY_ASPECT_RATIO  # type:ignore
KEY_ASSISTANT = e.KEY_ASSISTANT  # type:ignore
KEY_ATTENDANT_OFF = e.KEY_ATTENDANT_OFF  # type:ignore
KEY_ATTENDANT_ON = e.KEY_ATTENDANT_ON  # type:ignore
KEY_ATTENDANT_TOGGLE = e.KEY_ATTENDANT_TOGGLE  # type:ignore
KEY_AUDIO = e.KEY_AUDIO  # type:ignore
KEY_AUDIO_DESC = e.KEY_AUDIO_DESC  # type:ignore
KEY_AUX = e.KEY_AUX  # type:ignore
KEY_B = e.KEY_B  # type:ignore
KEY_BACK = e.KEY_BACK  # type:ignore
KEY_BACKSLASH = e.KEY_BACKSLASH  # type:ignore
KEY_BACKSPACE = e.KEY_BACKSPACE  # type:ignore
KEY_BASSBOOST = e.KEY_BASSBOOST  # type:ignore
KEY_BATTERY = e.KEY_BATTERY  # type:ignore
KEY_BLUE = e.KEY_BLUE  # type:ignore
KEY_BLUETOOTH = e.KEY_BLUETOOTH  # type:ignore
KEY_BOOKMARKS = e.KEY_BOOKMARKS  # type:ignore
KEY_BREAK = e.KEY_BREAK  # type:ignore
KEY_BRIGHTNESSDOWN = e.KEY_BRIGHTNESSDOWN  # type:ignore
KEY_BRIGHTNESSUP = e.KEY_BRIGHTNESSUP  # type:ignore
KEY_BRIGHTNESS_AUTO = e.KEY_BRIGHTNESS_AUTO  # type:ignore
KEY_BRIGHTNESS_CYCLE = e.KEY_BRIGHTNESS_CYCLE  # type:ignore
KEY_BRIGHTNESS_MAX = e.KEY_BRIGHTNESS_MAX  # type:ignore
KEY_BRIGHTNESS_MIN = e.KEY_BRIGHTNESS_MIN  # type:ignore
KEY_BRIGHTNESS_TOGGLE = e.KEY_BRIGHTNESS_TOGGLE  # type:ignore
KEY_BRIGHTNESS_ZERO = e.KEY_BRIGHTNESS_ZERO  # type:ignore
KEY_BRL_DOT1 = e.KEY_BRL_DOT1  # type:ignore
KEY_BRL_DOT10 = e.KEY_BRL_DOT10  # type:ignore
KEY_BRL_DOT2 = e.KEY_BRL_DOT2  # type:ignore
KEY_BRL_DOT3 = e.KEY_BRL_DOT3  # type:ignore
KEY_BRL_DOT4 = e.KEY_BRL_DOT4  # type:ignore
KEY_BRL_DOT5 = e.KEY_BRL_DOT5  # type:ignore
KEY_BRL_DOT6 = e.KEY_BRL_DOT6  # type:ignore
KEY_BRL_DOT7 = e.KEY_BRL_DOT7  # type:ignore
KEY_BRL_DOT8 = e.KEY_BRL_DOT8  # type:ignore
KEY_BRL_DOT9 = e.KEY_BRL_DOT9  # type:ignore
KEY_BUTTONCONFIG = e.KEY_BUTTONCONFIG  # type:ignore
KEY_C = e.KEY_C  # type:ignore
KEY_CALC = e.KEY_CALC  # type:ignore
KEY_CALENDAR = e.KEY_CALENDAR  # type:ignore
KEY_CAMERA = e.KEY_CAMERA  # type:ignore
KEY_CAMERA_DOWN = e.KEY_CAMERA_DOWN  # type:ignore
KEY_CAMERA_FOCUS = e.KEY_CAMERA_FOCUS  # type:ignore
KEY_CAMERA_LEFT = e.KEY_CAMERA_LEFT  # type:ignore
KEY_CAMERA_RIGHT = e.KEY_CAMERA_RIGHT  # type:ignore
KEY_CAMERA_UP = e.KEY_CAMERA_UP  # type:ignore
KEY_CAMERA_ZOOMIN = e.KEY_CAMERA_ZOOMIN  # type:ignore
KEY_CAMERA_ZOOMOUT = e.KEY_CAMERA_ZOOMOUT  # type:ignore
KEY_CANCEL = e.KEY_CANCEL  # type:ignore
KEY_CAPSLOCK = e.KEY_CAPSLOCK  # type:ignore
KEY_CD = e.KEY_CD  # type:ignore
KEY_CHANNEL = e.KEY_CHANNEL  # type:ignore
KEY_CHANNELDOWN = e.KEY_CHANNELDOWN  # type:ignore
KEY_CHANNELUP = e.KEY_CHANNELUP  # type:ignore
KEY_CHAT = e.KEY_CHAT  # type:ignore
KEY_CLEAR = e.KEY_CLEAR  # type:ignore
KEY_CLOSE = e.KEY_CLOSE  # type:ignore
KEY_CLOSECD = e.KEY_CLOSECD  # type:ignore
KEY_CNT = e.KEY_CNT  # type:ignore
KEY_COFFEE = e.KEY_COFFEE  # type:ignore
KEY_COMMA = e.KEY_COMMA  # type:ignore
KEY_COMPOSE = e.KEY_COMPOSE  # type:ignore
KEY_COMPUTER = e.KEY_COMPUTER  # type:ignore
KEY_CONFIG = e.KEY_CONFIG  # type:ignore
KEY_CONNECT = e.KEY_CONNECT  # type:ignore
KEY_CONTEXT_MENU = e.KEY_CONTEXT_MENU  # type:ignore
KEY_CONTROLPANEL = e.KEY_CONTROLPANEL  # type:ignore
KEY_COPY = e.KEY_COPY  # type:ignore
KEY_CUT = e.KEY_CUT  # type:ignore
KEY_CYCLEWINDOWS = e.KEY_CYCLEWINDOWS  # type:ignore
KEY_D = e.KEY_D  # type:ignore
KEY_DASHBOARD = e.KEY_DASHBOARD  # type:ignore
KEY_DATA = e.KEY_DATA  # type:ignore
KEY_DATABASE = e.KEY_DATABASE  # type:ignore
KEY_DELETE = e.KEY_DELETE  # type:ignore
KEY_DELETEFILE = e.KEY_DELETEFILE  # type:ignore
KEY_DEL_EOL = e.KEY_DEL_EOL  # type:ignore
KEY_DEL_EOS = e.KEY_DEL_EOS  # type:ignore
KEY_DEL_LINE = e.KEY_DEL_LINE  # type:ignore
KEY_DIGITS = e.KEY_DIGITS  # type:ignore
KEY_DIRECTION = e.KEY_DIRECTION  # type:ignore
KEY_DIRECTORY = e.KEY_DIRECTORY  # type:ignore
KEY_DISPLAYTOGGLE = e.KEY_DISPLAYTOGGLE  # type:ignore
KEY_DISPLAY_OFF = e.KEY_DISPLAY_OFF  # type:ignore
KEY_DOCUMENTS = e.KEY_DOCUMENTS  # type:ignore
KEY_DOLLAR = e.KEY_DOLLAR  # type:ignore
KEY_DOT = e.KEY_DOT  # type:ignore
KEY_DOWN = e.KEY_DOWN  # type:ignore
KEY_DVD = e.KEY_DVD  # type:ignore
KEY_E = e.KEY_E  # type:ignore
KEY_EDIT = e.KEY_EDIT  # type:ignore
KEY_EDITOR = e.KEY_EDITOR  # type:ignore
KEY_EJECTCD = e.KEY_EJECTCD  # type:ignore
KEY_EJECTCLOSECD = e.KEY_EJECTCLOSECD  # type:ignore
KEY_EMAIL = e.KEY_EMAIL  # type:ignore
KEY_END = e.KEY_END  # type:ignore
KEY_ENTER = e.KEY_ENTER  # type:ignore
KEY_EPG = e.KEY_EPG  # type:ignore
KEY_EQUAL = e.KEY_EQUAL  # type:ignore
KEY_ESC = e.KEY_ESC  # type:ignore
KEY_EURO = e.KEY_EURO  # type:ignore
KEY_EXIT = e.KEY_EXIT  # type:ignore
KEY_F = e.KEY_F  # type:ignore
KEY_F1 = e.KEY_F1  # type:ignore
KEY_F10 = e.KEY_F10  # type:ignore
KEY_F11 = e.KEY_F11  # type:ignore
KEY_F12 = e.KEY_F12  # type:ignore
KEY_F13 = e.KEY_F13  # type:ignore
KEY_F14 = e.KEY_F14  # type:ignore
KEY_F15 = e.KEY_F15  # type:ignore
KEY_F16 = e.KEY_F16  # type:ignore
KEY_F17 = e.KEY_F17  # type:ignore
KEY_F18 = e.KEY_F18  # type:ignore
KEY_F19 = e.KEY_F19  # type:ignore
KEY_F2 = e.KEY_F2  # type:ignore
KEY_F20 = e.KEY_F20  # type:ignore
KEY_F21 = e.KEY_F21  # type:ignore
KEY_F22 = e.KEY_F22  # type:ignore
KEY_F23 = e.KEY_F23  # type:ignore
KEY_F24 = e.KEY_F24  # type:ignore
KEY_F3 = e.KEY_F3  # type:ignore
KEY_F4 = e.KEY_F4  # type:ignore
KEY_F5 = e.KEY_F5  # type:ignore
KEY_F6 = e.KEY_F6  # type:ignore
KEY_F7 = e.KEY_F7  # type:ignore
KEY_F8 = e.KEY_F8  # type:ignore
KEY_F9 = e.KEY_F9  # type:ignore
KEY_FASTFORWARD = e.KEY_FASTFORWARD  # type:ignore
KEY_FASTREVERSE = e.KEY_FASTREVERSE  # type:ignore
KEY_FAVORITES = e.KEY_FAVORITES  # type:ignore
KEY_FILE = e.KEY_FILE  # type:ignore
KEY_FINANCE = e.KEY_FINANCE  # type:ignore
KEY_FIND = e.KEY_FIND  # type:ignore
KEY_FIRST = e.KEY_FIRST  # type:ignore
KEY_FN = e.KEY_FN  # type:ignore
KEY_FN_1 = e.KEY_FN_1  # type:ignore
KEY_FN_2 = e.KEY_FN_2  # type:ignore
KEY_FN_B = e.KEY_FN_B  # type:ignore
KEY_FN_D = e.KEY_FN_D  # type:ignore
KEY_FN_E = e.KEY_FN_E  # type:ignore
KEY_FN_ESC = e.KEY_FN_ESC  # type:ignore
KEY_FN_F = e.KEY_FN_F  # type:ignore
KEY_FN_F1 = e.KEY_FN_F1  # type:ignore
KEY_FN_F10 = e.KEY_FN_F10  # type:ignore
KEY_FN_F11 = e.KEY_FN_F11  # type:ignore
KEY_FN_F12 = e.KEY_FN_F12  # type:ignore
KEY_FN_F2 = e.KEY_FN_F2  # type:ignore
KEY_FN_F3 = e.KEY_FN_F3  # type:ignore
KEY_FN_F4 = e.KEY_FN_F4  # type:ignore
KEY_FN_F5 = e.KEY_FN_F5  # type:ignore
KEY_FN_F6 = e.KEY_FN_F6  # type:ignore
KEY_FN_F7 = e.KEY_FN_F7  # type:ignore
KEY_FN_F8 = e.KEY_FN_F8  # type:ignore
KEY_FN_F9 = e.KEY_FN_F9  # type:ignore
KEY_FN_RIGHT_SHIFT = e.KEY_FN_RIGHT_SHIFT  # type:ignore
KEY_FN_S = e.KEY_FN_S  # type:ignore
KEY_FORWARD = e.KEY_FORWARD  # type:ignore
KEY_FORWARDMAIL = e.KEY_FORWARDMAIL  # type:ignore
KEY_FRAMEBACK = e.KEY_FRAMEBACK  # type:ignore
KEY_FRAMEFORWARD = e.KEY_FRAMEFORWARD  # type:ignore
KEY_FRONT = e.KEY_FRONT  # type:ignore
KEY_FULL_SCREEN = e.KEY_FULL_SCREEN  # type:ignore
KEY_G = e.KEY_G  # type:ignore
KEY_GAMES = e.KEY_GAMES  # type:ignore
KEY_GOTO = e.KEY_GOTO  # type:ignore
KEY_GRAPHICSEDITOR = e.KEY_GRAPHICSEDITOR  # type:ignore
KEY_GRAVE = e.KEY_GRAVE  # type:ignore
KEY_GREEN = e.KEY_GREEN  # type:ignore
KEY_H = e.KEY_H  # type:ignore
KEY_HANGEUL = e.KEY_HANGEUL  # type:ignore
KEY_HANGUEL = e.KEY_HANGUEL  # type:ignore
KEY_HANGUP_PHONE = e.KEY_HANGUP_PHONE  # type:ignore
KEY_HANJA = e.KEY_HANJA  # type:ignore
KEY_HELP = e.KEY_HELP  # type:ignore
KEY_HENKAN = e.KEY_HENKAN  # type:ignore
KEY_HIRAGANA = e.KEY_HIRAGANA  # type:ignore
KEY_HOME = e.KEY_HOME  # type:ignore
KEY_HOMEPAGE = e.KEY_HOMEPAGE  # type:ignore
KEY_HP = e.KEY_HP  # type:ignore
KEY_I = e.KEY_I  # type:ignore
KEY_IMAGES = e.KEY_IMAGES  # type:ignore
KEY_INFO = e.KEY_INFO  # type:ignore
KEY_INSERT = e.KEY_INSERT  # type:ignore
KEY_INS_LINE = e.KEY_INS_LINE  # type:ignore
KEY_ISO = e.KEY_ISO  # type:ignore
KEY_J = e.KEY_J  # type:ignore
KEY_JOURNAL = e.KEY_JOURNAL  # type:ignore
KEY_K = e.KEY_K  # type:ignore
KEY_KATAKANA = e.KEY_KATAKANA  # type:ignore
KEY_KATAKANAHIRAGANA = e.KEY_KATAKANAHIRAGANA  # type:ignore
KEY_KBDILLUMDOWN = e.KEY_KBDILLUMDOWN  # type:ignore
KEY_KBDILLUMTOGGLE = e.KEY_KBDILLUMTOGGLE  # type:ignore
KEY_KBDILLUMUP = e.KEY_KBDILLUMUP  # type:ignore
KEY_KBDINPUTASSIST_ACCEPT = e.KEY_KBDINPUTASSIST_ACCEPT  # type:ignore
KEY_KBDINPUTASSIST_CANCEL = e.KEY_KBDINPUTASSIST_CANCEL  # type:ignore
KEY_KBDINPUTASSIST_NEXT = e.KEY_KBDINPUTASSIST_NEXT  # type:ignore
KEY_KBDINPUTASSIST_NEXTGROUP = e.KEY_KBDINPUTASSIST_NEXTGROUP  # type:ignore
KEY_KBDINPUTASSIST_PREV = e.KEY_KBDINPUTASSIST_PREV  # type:ignore
KEY_KBDINPUTASSIST_PREVGROUP = e.KEY_KBDINPUTASSIST_PREVGROUP  # type:ignore
KEY_KBD_LAYOUT_NEXT = e.KEY_KBD_LAYOUT_NEXT  # type:ignore
KEY_KBD_LCD_MENU1 = e.KEY_KBD_LCD_MENU1  # type:ignore
KEY_KBD_LCD_MENU2 = e.KEY_KBD_LCD_MENU2  # type:ignore
KEY_KBD_LCD_MENU3 = e.KEY_KBD_LCD_MENU3  # type:ignore
KEY_KBD_LCD_MENU4 = e.KEY_KBD_LCD_MENU4  # type:ignore
KEY_KBD_LCD_MENU5 = e.KEY_KBD_LCD_MENU5  # type:ignore
KEY_KEYBOARD = e.KEY_KEYBOARD  # type:ignore
KEY_KP0 = e.KEY_KP0  # type:ignore
KEY_KP1 = e.KEY_KP1  # type:ignore
KEY_KP2 = e.KEY_KP2  # type:ignore
KEY_KP3 = e.KEY_KP3  # type:ignore
KEY_KP4 = e.KEY_KP4  # type:ignore
KEY_KP5 = e.KEY_KP5  # type:ignore
KEY_KP6 = e.KEY_KP6  # type:ignore
KEY_KP7 = e.KEY_KP7  # type:ignore
KEY_KP8 = e.KEY_KP8  # type:ignore
KEY_KP9 = e.KEY_KP9  # type:ignore
KEY_KPASTERISK = e.KEY_KPASTERISK  # type:ignore
KEY_KPCOMMA = e.KEY_KPCOMMA  # type:ignore
KEY_KPDOT = e.KEY_KPDOT  # type:ignore
KEY_KPENTER = e.KEY_KPENTER  # type:ignore
KEY_KPEQUAL = e.KEY_KPEQUAL  # type:ignore
KEY_KPJPCOMMA = e.KEY_KPJPCOMMA  # type:ignore
KEY_KPLEFTPAREN = e.KEY_KPLEFTPAREN  # type:ignore
KEY_KPMINUS = e.KEY_KPMINUS  # type:ignore
KEY_KPPLUS = e.KEY_KPPLUS  # type:ignore
KEY_KPPLUSMINUS = e.KEY_KPPLUSMINUS  # type:ignore
KEY_KPRIGHTPAREN = e.KEY_KPRIGHTPAREN  # type:ignore
KEY_KPSLASH = e.KEY_KPSLASH  # type:ignore
KEY_L = e.KEY_L  # type:ignore
KEY_LANGUAGE = e.KEY_LANGUAGE  # type:ignore
KEY_LAST = e.KEY_LAST  # type:ignore
KEY_LEFT = e.KEY_LEFT  # type:ignore
KEY_LEFTALT = e.KEY_LEFTALT  # type:ignore
KEY_LEFTBRACE = e.KEY_LEFTBRACE  # type:ignore
KEY_LEFTCTRL = e.KEY_LEFTCTRL  # type:ignore
KEY_LEFTMETA = e.KEY_LEFTMETA  # type:ignore
KEY_LEFTSHIFT = e.KEY_LEFTSHIFT  # type:ignore
KEY_LEFT_DOWN = e.KEY_LEFT_DOWN  # type:ignore
KEY_LEFT_UP = e.KEY_LEFT_UP  # type:ignore
KEY_LIGHTS_TOGGLE = e.KEY_LIGHTS_TOGGLE  # type:ignore
KEY_LINEFEED = e.KEY_LINEFEED  # type:ignore
KEY_LIST = e.KEY_LIST  # type:ignore
KEY_LOGOFF = e.KEY_LOGOFF  # type:ignore
KEY_M = e.KEY_M  # type:ignore
KEY_MACRO = e.KEY_MACRO  # type:ignore
KEY_MACRO1 = e.KEY_MACRO1  # type:ignore
KEY_MACRO10 = e.KEY_MACRO10  # type:ignore
KEY_MACRO11 = e.KEY_MACRO11  # type:ignore
KEY_MACRO12 = e.KEY_MACRO12  # type:ignore
KEY_MACRO13 = e.KEY_MACRO13  # type:ignore
KEY_MACRO14 = e.KEY_MACRO14  # type:ignore
KEY_MACRO15 = e.KEY_MACRO15  # type:ignore
KEY_MACRO16 = e.KEY_MACRO16  # type:ignore
KEY_MACRO17 = e.KEY_MACRO17  # type:ignore
KEY_MACRO18 = e.KEY_MACRO18  # type:ignore
KEY_MACRO19 = e.KEY_MACRO19  # type:ignore
KEY_MACRO2 = e.KEY_MACRO2  # type:ignore
KEY_MACRO20 = e.KEY_MACRO20  # type:ignore
KEY_MACRO21 = e.KEY_MACRO21  # type:ignore
KEY_MACRO22 = e.KEY_MACRO22  # type:ignore
KEY_MACRO23 = e.KEY_MACRO23  # type:ignore
KEY_MACRO24 = e.KEY_MACRO24  # type:ignore
KEY_MACRO25 = e.KEY_MACRO25  # type:ignore
KEY_MACRO26 = e.KEY_MACRO26  # type:ignore
KEY_MACRO27 = e.KEY_MACRO27  # type:ignore
KEY_MACRO28 = e.KEY_MACRO28  # type:ignore
KEY_MACRO29 = e.KEY_MACRO29  # type:ignore
KEY_MACRO3 = e.KEY_MACRO3  # type:ignore
KEY_MACRO30 = e.KEY_MACRO30  # type:ignore
KEY_MACRO4 = e.KEY_MACRO4  # type:ignore
KEY_MACRO5 = e.KEY_MACRO5  # type:ignore
KEY_MACRO6 = e.KEY_MACRO6  # type:ignore
KEY_MACRO7 = e.KEY_MACRO7  # type:ignore
KEY_MACRO8 = e.KEY_MACRO8  # type:ignore
KEY_MACRO9 = e.KEY_MACRO9  # type:ignore
KEY_MACRO_PRESET1 = e.KEY_MACRO_PRESET1  # type:ignore
KEY_MACRO_PRESET2 = e.KEY_MACRO_PRESET2  # type:ignore
KEY_MACRO_PRESET3 = e.KEY_MACRO_PRESET3  # type:ignore
KEY_MACRO_PRESET_CYCLE = e.KEY_MACRO_PRESET_CYCLE  # type:ignore
KEY_MACRO_RECORD_START = e.KEY_MACRO_RECORD_START  # type:ignore
KEY_MACRO_RECORD_STOP = e.KEY_MACRO_RECORD_STOP  # type:ignore
KEY_MAIL = e.KEY_MAIL  # type:ignore
KEY_MAX = e.KEY_MAX  # type:ignore
KEY_MEDIA = e.KEY_MEDIA  # type:ignore
KEY_MEDIA_REPEAT = e.KEY_MEDIA_REPEAT  # type:ignore
KEY_MEDIA_TOP_MENU = e.KEY_MEDIA_TOP_MENU  # type:ignore
KEY_MEMO = e.KEY_MEMO  # type:ignore
KEY_MENU = e.KEY_MENU  # type:ignore
KEY_MESSENGER = e.KEY_MESSENGER  # type:ignore
KEY_MHP = e.KEY_MHP  # type:ignore
KEY_MICMUTE = e.KEY_MICMUTE  # type:ignore
KEY_MINUS = e.KEY_MINUS  # type:ignore
KEY_MIN_INTERESTING = e.KEY_MIN_INTERESTING  # type:ignore
KEY_MODE = e.KEY_MODE  # type:ignore
KEY_MOVE = e.KEY_MOVE  # type:ignore
KEY_MP3 = e.KEY_MP3  # type:ignore
KEY_MSDOS = e.KEY_MSDOS  # type:ignore
KEY_MUHENKAN = e.KEY_MUHENKAN  # type:ignore
KEY_MUTE = e.KEY_MUTE  # type:ignore
KEY_N = e.KEY_N  # type:ignore
KEY_NEW = e.KEY_NEW  # type:ignore
KEY_NEWS = e.KEY_NEWS  # type:ignore
KEY_NEXT = e.KEY_NEXT  # type:ignore
KEY_NEXTSONG = e.KEY_NEXTSONG  # type:ignore
KEY_NEXT_FAVORITE = e.KEY_NEXT_FAVORITE  # type:ignore
KEY_NOTIFICATION_CENTER = e.KEY_NOTIFICATION_CENTER  # type:ignore
KEY_NUMERIC_0 = e.KEY_NUMERIC_0  # type:ignore
KEY_NUMERIC_1 = e.KEY_NUMERIC_1  # type:ignore
KEY_NUMERIC_11 = e.KEY_NUMERIC_11  # type:ignore
KEY_NUMERIC_12 = e.KEY_NUMERIC_12  # type:ignore
KEY_NUMERIC_2 = e.KEY_NUMERIC_2  # type:ignore
KEY_NUMERIC_3 = e.KEY_NUMERIC_3  # type:ignore
KEY_NUMERIC_4 = e.KEY_NUMERIC_4  # type:ignore
KEY_NUMERIC_5 = e.KEY_NUMERIC_5  # type:ignore
KEY_NUMERIC_6 = e.KEY_NUMERIC_6  # type:ignore
KEY_NUMERIC_7 = e.KEY_NUMERIC_7  # type:ignore
KEY_NUMERIC_8 = e.KEY_NUMERIC_8  # type:ignore
KEY_NUMERIC_9 = e.KEY_NUMERIC_9  # type:ignore
KEY_NUMERIC_A = e.KEY_NUMERIC_A  # type:ignore
KEY_NUMERIC_B = e.KEY_NUMERIC_B  # type:ignore
KEY_NUMERIC_C = e.KEY_NUMERIC_C  # type:ignore
KEY_NUMERIC_D = e.KEY_NUMERIC_D  # type:ignore
KEY_NUMERIC_POUND = e.KEY_NUMERIC_POUND  # type:ignore
KEY_NUMERIC_STAR = e.KEY_NUMERIC_STAR  # type:ignore
KEY_NUMLOCK = e.KEY_NUMLOCK  # type:ignore
KEY_O = e.KEY_O  # type:ignore
KEY_OK = e.KEY_OK  # type:ignore
KEY_ONSCREEN_KEYBOARD = e.KEY_ONSCREEN_KEYBOARD  # type:ignore
KEY_OPEN = e.KEY_OPEN  # type:ignore
KEY_OPTION = e.KEY_OPTION  # type:ignore
KEY_P = e.KEY_P  # type:ignore
KEY_PAGEDOWN = e.KEY_PAGEDOWN  # type:ignore
KEY_PAGEUP = e.KEY_PAGEUP  # type:ignore
KEY_PASTE = e.KEY_PASTE  # type:ignore
KEY_PAUSE = e.KEY_PAUSE  # type:ignore
KEY_PAUSECD = e.KEY_PAUSECD  # type:ignore
KEY_PAUSE_RECORD = e.KEY_PAUSE_RECORD  # type:ignore
KEY_PC = e.KEY_PC  # type:ignore
KEY_PHONE = e.KEY_PHONE  # type:ignore
KEY_PICKUP_PHONE = e.KEY_PICKUP_PHONE  # type:ignore
KEY_PLAY = e.KEY_PLAY  # type:ignore
KEY_PLAYCD = e.KEY_PLAYCD  # type:ignore
KEY_PLAYER = e.KEY_PLAYER  # type:ignore
KEY_PLAYPAUSE = e.KEY_PLAYPAUSE  # type:ignore
KEY_POWER = e.KEY_POWER  # type:ignore
KEY_POWER2 = e.KEY_POWER2  # type:ignore
KEY_PRESENTATION = e.KEY_PRESENTATION  # type:ignore
KEY_PREVIOUS = e.KEY_PREVIOUS  # type:ignore
KEY_PREVIOUSSONG = e.KEY_PREVIOUSSONG  # type:ignore
KEY_PRINT = e.KEY_PRINT  # type:ignore
KEY_PRIVACY_SCREEN_TOGGLE = e.KEY_PRIVACY_SCREEN_TOGGLE  # type:ignore
KEY_PROG1 = e.KEY_PROG1  # type:ignore
KEY_PROG2 = e.KEY_PROG2  # type:ignore
KEY_PROG3 = e.KEY_PROG3  # type:ignore
KEY_PROG4 = e.KEY_PROG4  # type:ignore
KEY_PROGRAM = e.KEY_PROGRAM  # type:ignore
KEY_PROPS = e.KEY_PROPS  # type:ignore
KEY_PVR = e.KEY_PVR  # type:ignore
KEY_Q = e.KEY_Q  # type:ignore
KEY_QUESTION = e.KEY_QUESTION  # type:ignore
KEY_R = e.KEY_R  # type:ignore
KEY_RADIO = e.KEY_RADIO  # type:ignore
KEY_RECORD = e.KEY_RECORD  # type:ignore
KEY_RED = e.KEY_RED  # type:ignore
KEY_REDO = e.KEY_REDO  # type:ignore
KEY_REFRESH = e.KEY_REFRESH  # type:ignore
KEY_REPLY = e.KEY_REPLY  # type:ignore
KEY_RESERVED = e.KEY_RESERVED  # type:ignore
KEY_RESTART = e.KEY_RESTART  # type:ignore
KEY_REWIND = e.KEY_REWIND  # type:ignore
KEY_RFKILL = e.KEY_RFKILL  # type:ignore
KEY_RIGHT = e.KEY_RIGHT  # type:ignore
KEY_RIGHTALT = e.KEY_RIGHTALT  # type:ignore
KEY_RIGHTBRACE = e.KEY_RIGHTBRACE  # type:ignore
KEY_RIGHTCTRL = e.KEY_RIGHTCTRL  # type:ignore
KEY_RIGHTMETA = e.KEY_RIGHTMETA  # type:ignore
KEY_RIGHTSHIFT = e.KEY_RIGHTSHIFT  # type:ignore
KEY_RIGHT_DOWN = e.KEY_RIGHT_DOWN  # type:ignore
KEY_RIGHT_UP = e.KEY_RIGHT_UP  # type:ignore
KEY_RO = e.KEY_RO  # type:ignore
KEY_ROOT_MENU = e.KEY_ROOT_MENU  # type:ignore
KEY_ROTATE_DISPLAY = e.KEY_ROTATE_DISPLAY  # type:ignore
KEY_ROTATE_LOCK_TOGGLE = e.KEY_ROTATE_LOCK_TOGGLE  # type:ignore
KEY_S = e.KEY_S  # type:ignore
KEY_SAT = e.KEY_SAT  # type:ignore
KEY_SAT2 = e.KEY_SAT2  # type:ignore
KEY_SAVE = e.KEY_SAVE  # type:ignore
KEY_SCALE = e.KEY_SCALE  # type:ignore
KEY_SCREEN = e.KEY_SCREEN  # type:ignore
KEY_SCREENLOCK = e.KEY_SCREENLOCK  # type:ignore
KEY_SCREENSAVER = e.KEY_SCREENSAVER  # type:ignore
KEY_SCROLLDOWN = e.KEY_SCROLLDOWN  # type:ignore
KEY_SCROLLLOCK = e.KEY_SCROLLLOCK  # type:ignore
KEY_SCROLLUP = e.KEY_SCROLLUP  # type:ignore
KEY_SEARCH = e.KEY_SEARCH  # type:ignore
KEY_SELECT = e.KEY_SELECT  # type:ignore
KEY_SELECTIVE_SCREENSHOT = e.KEY_SELECTIVE_SCREENSHOT  # type:ignore
KEY_SEMICOLON = e.KEY_SEMICOLON  # type:ignore
KEY_SEND = e.KEY_SEND  # type:ignore
KEY_SENDFILE = e.KEY_SENDFILE  # type:ignore
KEY_SETUP = e.KEY_SETUP  # type:ignore
KEY_SHOP = e.KEY_SHOP  # type:ignore
KEY_SHUFFLE = e.KEY_SHUFFLE  # type:ignore
KEY_SLASH = e.KEY_SLASH  # type:ignore
KEY_SLEEP = e.KEY_SLEEP  # type:ignore
KEY_SLOW = e.KEY_SLOW  # type:ignore
KEY_SLOWREVERSE = e.KEY_SLOWREVERSE  # type:ignore
KEY_SOUND = e.KEY_SOUND  # type:ignore
KEY_SPACE = e.KEY_SPACE  # type:ignore
KEY_SPELLCHECK = e.KEY_SPELLCHECK  # type:ignore
KEY_SPORT = e.KEY_SPORT  # type:ignore
KEY_SPREADSHEET = e.KEY_SPREADSHEET  # type:ignore
KEY_STOP = e.KEY_STOP  # type:ignore
KEY_STOPCD = e.KEY_STOPCD  # type:ignore
KEY_STOP_RECORD = e.KEY_STOP_RECORD  # type:ignore
KEY_SUBTITLE = e.KEY_SUBTITLE  # type:ignore
KEY_SUSPEND = e.KEY_SUSPEND  # type:ignore
KEY_SWITCHVIDEOMODE = e.KEY_SWITCHVIDEOMODE  # type:ignore
KEY_SYSRQ = e.KEY_SYSRQ  # type:ignore
KEY_T = e.KEY_T  # type:ignore
KEY_TAB = e.KEY_TAB  # type:ignore
KEY_TAPE = e.KEY_TAPE  # type:ignore
KEY_TASKMANAGER = e.KEY_TASKMANAGER  # type:ignore
KEY_TEEN = e.KEY_TEEN  # type:ignore
KEY_TEXT = e.KEY_TEXT  # type:ignore
KEY_TIME = e.KEY_TIME  # type:ignore
KEY_TITLE = e.KEY_TITLE  # type:ignore
KEY_TOUCHPAD_OFF = e.KEY_TOUCHPAD_OFF  # type:ignore
KEY_TOUCHPAD_ON = e.KEY_TOUCHPAD_ON  # type:ignore
KEY_TOUCHPAD_TOGGLE = e.KEY_TOUCHPAD_TOGGLE  # type:ignore
KEY_TUNER = e.KEY_TUNER  # type:ignore
KEY_TV = e.KEY_TV  # type:ignore
KEY_TV2 = e.KEY_TV2  # type:ignore
KEY_TWEN = e.KEY_TWEN  # type:ignore
KEY_U = e.KEY_U  # type:ignore
KEY_UNDO = e.KEY_UNDO  # type:ignore
KEY_UNKNOWN = e.KEY_UNKNOWN  # type:ignore
KEY_UNMUTE = e.KEY_UNMUTE  # type:ignore
KEY_UP = e.KEY_UP  # type:ignore
KEY_UWB = e.KEY_UWB  # type:ignore
KEY_V = e.KEY_V  # type:ignore
KEY_VCR = e.KEY_VCR  # type:ignore
KEY_VCR2 = e.KEY_VCR2  # type:ignore
KEY_VENDOR = e.KEY_VENDOR  # type:ignore
KEY_VIDEO = e.KEY_VIDEO  # type:ignore
KEY_VIDEOPHONE = e.KEY_VIDEOPHONE  # type:ignore
KEY_VIDEO_NEXT = e.KEY_VIDEO_NEXT  # type:ignore
KEY_VIDEO_PREV = e.KEY_VIDEO_PREV  # type:ignore
KEY_VOD = e.KEY_VOD  # type:ignore
KEY_VOICECOMMAND = e.KEY_VOICECOMMAND  # type:ignore
KEY_VOICEMAIL = e.KEY_VOICEMAIL  # type:ignore
KEY_VOLUMEDOWN = e.KEY_VOLUMEDOWN  # type:ignore
KEY_VOLUMEUP = e.KEY_VOLUMEUP  # type:ignore
KEY_W = e.KEY_W  # type:ignore
KEY_WAKEUP = e.KEY_WAKEUP  # type:ignore
KEY_WIMAX = e.KEY_WIMAX  # type:ignore
KEY_WLAN = e.KEY_WLAN  # type:ignore
KEY_WORDPROCESSOR = e.KEY_WORDPROCESSOR  # type:ignore
KEY_WPS_BUTTON = e.KEY_WPS_BUTTON  # type:ignore
KEY_WWAN = e.KEY_WWAN  # type:ignore
KEY_WWW = e.KEY_WWW  # type:ignore
KEY_X = e.KEY_X  # type:ignore
KEY_XFER = e.KEY_XFER  # type:ignore
KEY_Y = e.KEY_Y  # type:ignore
KEY_YELLOW = e.KEY_YELLOW  # type:ignore
KEY_YEN = e.KEY_YEN  # type:ignore
KEY_Z = e.KEY_Z  # type:ignore
KEY_ZENKAKUHANKAKU = e.KEY_ZENKAKUHANKAKU  # type:ignore
KEY_ZOOM = e.KEY_ZOOM  # type:ignore
KEY_ZOOMIN = e.KEY_ZOOMIN  # type:ignore
KEY_ZOOMOUT = e.KEY_ZOOMOUT  # type:ignore
KEY_ZOOMRESET = e.KEY_ZOOMRESET  # type:ignore
